==> haskell-xml-hamlet-0.5.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.5.0
id: xml-hamlet-0.5.0-B4wUGyRcdS99KjmAAG1TZE
key: xml-hamlet-0.5.0-B4wUGyRcdS99KjmAAG1TZE
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
abi: 6c1e28913c37f73c4f0819c9f368ddff
exposed: True
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
import-dirs: /usr/lib/ghc-8.4.3/site-local/xml-hamlet-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/xml-hamlet-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/xml-hamlet-0.5.0
hs-libraries: HSxml-hamlet-0.5.0-B4wUGyRcdS99KjmAAG1TZE
depends:
    base-4.11.1.0 shakespeare-2.0.15-FZV6ssjAVxcCkg2QuDwMyP
    xml-conduit-1.8.0-Jmx4rS4cyWJGuWhAkiF9gZ text-1.2.3.0
    template-haskell-2.13.0.0 parsec-3.1.13.0 containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             shakespeare-2.0.15-FZV6ssjAVxcCkg2QuDwMyP=0c223dbb3f0a88bbe46ced9c0d77e0f4
             xml-conduit-1.8.0-Jmx4rS4cyWJGuWhAkiF9gZ=d1cc317765794404014ccc0874f2fc4e
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.5.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.5.0
id: xml-hamlet-0.5.0-GRjkRNr8XRdHUtuNNVXejV
key: xml-hamlet-0.5.0-GRjkRNr8XRdHUtuNNVXejV
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
abi: 98c46048f4e9dc23ba21e36155e14f46
exposed: True
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
import-dirs: /usr/lib/ghc-8.4.3/site-local/xml-hamlet-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/xml-hamlet-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/xml-hamlet-0.5.0
hs-libraries: HSxml-hamlet-0.5.0-GRjkRNr8XRdHUtuNNVXejV
depends:
    base-4.11.1.0 shakespeare-2.0.15-FZV6ssjAVxcCkg2QuDwMyP
    xml-conduit-1.8.0-dgTSB6dP0TD4Km2sm8r0D text-1.2.3.0
    template-haskell-2.13.0.0 parsec-3.1.13.0 containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             shakespeare-2.0.15-FZV6ssjAVxcCkg2QuDwMyP=0c223dbb3f0a88bbe46ced9c0d77e0f4
             xml-conduit-1.8.0-dgTSB6dP0TD4Km2sm8r0D=24a05cea009860b43ecc5164e38619c6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
